/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.application;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.transport.*;
import com.monica.javacom.ciphering.*;
import com.monica.javacom.manager.*;
import com.monica.javacom.protocol.*;
import com.monica.javacom.terminal.*;
import com.monica.javacom.virtualinput.*;
import com.monica.javacom.virtualdisplay.*;
import com.monica.javacom.window.*;
import com.monica.javacom.application.*;
import com.monica.javacom.util.*;
import com.monica.javacom.ssh.*;

import java.io.*;
import java.awt.*;
import java.awt.event.*;

/** Class for running the client side functionality of the SSH2 protocol. This class has to
    be run fromt he command line.
    <b>Usage: java com.monica.javacom.application.MJCSSHClient destHost destPort</b><br><br>
    The configuration data will be read from ./MJC.conf and the softfont configuration 
    from ./fonts.conf.
*/
public class MJCSSHClient {

  /** Entry point for the JAVA VM.
      @param String[] args: the command line parameters
  */
  public static void main(String[] args) {
    if (args.length>=2) {

      // parsing cmdline

      String host=args[args.length-2];
      int port=Integer.parseInt(args[args.length-1]);

      MJCConfiguration configuration=new MJCFileConfiguration();
      
      try {
        configuration.setStream("fonts.conf", new FileInputStream("fonts.conf"));
      }
      catch (Exception e) {
        e.printStackTrace();
      }		

      MJCTransport transport=new MJCTCPTransport();
      MJCSSHTransportLayer tl=new MJCSSHTransportLayer();
      MJCTerminal terminal=new MJCVT220Terminal();
      MJCVirtualDisplay display=new MJCAWTDisplay(configuration);
      MJCVirtualInput input=new MJCKeyListener();
      MJCWindow window=new MJCAWTWindow(display, configuration, (KeyListener)input);

      transport.setReader(tl);
      transport.setConfiguration(configuration);

      tl.setWriteable(transport);
      tl.setReadable(transport);
      tl.setReader(terminal);
      tl.setWindow(window);
      tl.setTransport(transport);
      tl.setConfiguration(configuration);

      terminal.setReadable(tl);
      terminal.setConfiguration(configuration);
      terminal.setWriteable(tl);
      terminal.setVirtualDisplay(display);

//      display.setConfiguration(configuration);

      window.setConfiguration(configuration);
      window.setCloser(tl);

      input.setConfiguration(configuration);
      input.setWriteable(terminal);

      ((Frame)window).setVisible(true);

      try {
        transport.initAsClient(host, port);
      }
      catch (Exception e) {
        display.clear();
        display.setCPos(0,0);
        display.addS("Connection to the server could not be established. Reason: "+e.toString());
        display.refresh();
      }

      Object o=new Object();
      try {
        synchronized (o) {
	        o.wait();
	      }
      }
      catch (Exception e) {
      }
    }
    else {
      System.out.println("Usage: ");
      System.out.println("java MJCSSHClient destHost destPort");
      System.exit(0);
    }
  }
}