/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** Cipher algorithm for the SSH layer. Provides functionality for encryption/decryption.
    <b>Using the same instance of classes implementing this interface for both encyption and
    decyption is not supported.</b>
*/

public interface MJCSSHCipherAlgorithm {

  /** Returns the MJC name of the of the MJCSSHCipherAlgorithm.
      @return String: the MJC name of the MJCSSHCipherAlgorithm
  */
  public String getCipherAlgorithmName();
  
  /** Returns the MJC version of the MJCSSHCipherAlgorithm.
      @return String: the MJC version of the MJCSSHCipherAlgorithm
  */
  public String getCipherAlgorithmVersion();
  
  /** Method for setting the cryptographic key and the initialization vector.
      @param String key: the key for the cryptography
      @param string IV: the initialization vector
  */
  public void setKeys(String Key, String IV); 
  
  /** Returns the state of the cipher mechanism. This state can be restored with the setState
      method.
      @return Object: the state of the cipher mechanism
  */  
  public Object getState();
  
  /** Sets the state of the cipher mechanism.
      @param Object o: the to be set state of the cipher mechanism 
  */
  public void setState(Object state);

  /** Method for encryption of a String. The to be encrypted String has to be of a length
      that is a multipy of getCipherBlockSize(). Encryption is done with the key set with
      setKeys(String, String).
      @param String s: the String to be encrypted
      @return String: the encrypted String
  */
  public String encode(String data);
  
  /** Method for decryption of a String. The to be decrypted String has to be of a length
      that is a multiply of getCipherBlockSize(). Decryption is done with the key set with
      setKeys(String, String).
      @param String s: the String to be decrypted
      @return String: the decrypted String
  */
  public String decode(String coded_data);

  /** Returns the length of the minimal encryption length. Strings for encryption/decryption
      have to be of a length that is a multiply of this.
      @return int: the minimal encryption length
  */      
  public int getCipherBlockSize();
}

