/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import java.math.*;

/** Hash algorithm used by the SSH layer. Provides functionality for hashing Strings.
*/

public interface MJCSSHHashAlgorithm {

  /** Returns the MJC name of the MJCSSHHashAlgorithm.
      @return String: the MJC name of the MJCSSHHashAlgorithm
  */      
  public String getHashAlgorithmName();
  
  /** Returns the MJC version of the MJCSSHHashAlgorithm.
      @return String: the MJC version of the MJCSSHHashAlgorithm
  */      
  public String getHashAlgorithmVersion();

  /** Returns the hash value of the given String.
      @param String s: the String to be hashed
      @return String: the hash value of the given String
  */      
  public String hash(String s);
  
  /** Returns the hash value of the given String as BigInteger. Converting 
      the hash value from String to BigInteger is done as follows: the String
      hash value is interpreted as a nonnegative integer number with s.charAt(0)
      as MSB and s.charAt(s.length()-1) as LSB.
      @param String s: the String to be hashed
      @return BigInteger: the hash value of the given String
  */      
  public BigInteger hashAsBigInteger(String s);
  
  /** Returns the length of the hash value (as String) in number of bytes.
      @return int: the length of the hash value
  */      
  public int getHashLength();
}
