/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import com.monica.javacom.interfaces.*;

/** Provides Message Authentication functionality for the SSH layer.
*/
public interface MJCSSHMACAlgorithm {

  /** Returns the MJC name of the MJCSSHMACAlgorithm.
      @return String: the MJC name of the MJCSSHMACAlgorithm
  */      
  public String getMACAlgorithmName();
  
  /** Returns the MJC version of the MJCSSHMACAlgorithm.
      @return String: the MJC version of the MJCSSHMACAlgorithm
  */      
  public String getMACAlgorithmVersion();

  /** Creates the Message Authentication Code for the provided String (data) 
      according to the provided shared secret String (secret).
      @param String data: the data for which the MAC has to be created
      @param String secret: the shared secret for the MAC creation
      @return String: the resulting MAC
  */            
  public String createMAC(String data, String secret);
  
  /** Authenticates a message String (data) with a specified MAC String (MAC) accoring
      to the specified shared secret String (secret). Returns true if Message
      Authentication was successful.
      @param String data: the message body
      @param String MAC: the Message Authentication Code for the message body
      @param String secret: the shared secret for authenticating
      @return boolean: wether the authentication was successful or not
  */      
  public boolean authenticate(String data, String MAC, String secret);

  /** Return the length of the MAC in bytes.
      @return int: the length of the MAC in bytes
  */      
  public int getMACLength();
}