/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.interfaces;

import java.awt.*;
import java.io.*;

/** Provides functionality for drawing fixed space text on the graphical display.
    This interface is also referenced as "<b>text renderer</b>" for the MJCVirtualDisplay.
*/
public interface MJCText {

  /** Returns the MJC name of the MJCText.
      @return String: the MJC name of the MJCText
  */      
  public String getTextName();
  
  /** Returns the MJC version of the MJCText.
      @return String: the MJC version of the MJCText
  */      
  public String getTextVersion();

  /** Initializes the MJCText by specifying charWith, charHeight and an InputStream
      for configuration processing.
      @param int sX: the charWith in pixels
      @param int sY: the charheight in pixels
      @param InputStream is: the configuration InputStream
  */      
  public void init(int sX, int sY, InputStream is);
  
  /** Returns the charWidth of a single character.
      @return int: the charWidth of a single characted
  */      
  public int getWidth();
  
  /** Returns the charHeight of a single character.
      @return int: the charHeight of a single character
  */      
  public int getHeight();
  
  /** Draws the specified character (c) at the specified position (x,y: lower left corner)
      with the specified foregroung (f) and background (b) colors on the specified Graphics (g).
      @param char c: the char to be drawn
      @param int x: the left X coordinate of the char
      @param int y: the lower Y coordinate of the char
      @param Color f: the foreground color of the char
      @param Color b: the background color of the char
      @param Graphics g: the Graphics on that the char is drawn
  */
  public void drawChar(char c, int x, int y, Color f, Color b, Graphics g);
}