/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ssh;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.ssh.*;
import com.monica.javacom.util.*;

import java.util.*;
import java.math.*;
import java.io.*;

/** This class provides HMAC Message Authentication as defined in RFC-2104. */
public class MJCSSHHMAC implements MJCSSHMACAlgorithm {

  private static final String NAME="MJCSSHHMAC";
  private static final String VERSION="0.2";

  private int B, L;
  private String ipad, opad;

  String s1, s2, s3, s4, s5, s6, s7;

  private MJCSSHHashAlgorithm hash;

  /** Default constructor. For HMAC to be functional, a hash algorithm
      is required. This has to be provided as parameter.
      @param MJCSSHHashAlgorithm h: the hash algorithm that is required by HMAC
  */
  public MJCSSHHMAC(MJCSSHHashAlgorithm h) {
    hash=h;
    B=64;
    L=hash.getHashLength();
    char c[]=new char[B];
    for (int i=0; i<B; i++) c[i]=((char)0x36);
    ipad=new String(c);
    for (int i=0; i<B; i++) c[i]=((char)0x5C);
    opad=new String(c);
  }

  public String getMACAlgorithmName() {
    return NAME;
  }

  public String getMACAlgorithmVersion() {
    return VERSION;
  }

  public String createMAC(String data, String K) {

    // 0 //

    if (K.length()>B) {
      K=hash.hash(K);
    }

    // 1 //
    s1=new String(K);
    if (s1.length()<B) {
      for (int i=s1.length(); i<B; i++) {
        s1=s1.concat(""+((char)0));
      }
    }

    // 2 //
    s2=XOR(s1,ipad);

    // 3 //
    s3=s2.concat(data);

    // 4 //
    s4=hash.hash(s3);

    // 5 //
    s5=XOR(s1,opad);

    // 6 //
    s6=s5.concat(s4);

    // 7 //
    s7=hash.hash(s6);

    return s7;
  }

  public boolean authenticate(String data, String MAC, String K) {
    String cMAC=createMAC(data, K);

    return cMAC.equals(MAC);
  }

  public int getMACLength() {
    return hash.getHashLength();
  }

  private String XOR(String x1, String x2) {
    char c[]=new char[x1.length()];
    for (int i=0; i<x1.length(); i++) {
      c[i]=(char)(((int)(x1.charAt(i)))^((int)(x2.charAt(i))));
    }
    return new String(c);
  }

  private void dumpString(String d, PrintStream p) {
    p.println("LEN="+d.length());
    p.println(d);
    for (int i=0; i<d.length(); i++) {
      // System.out.println(""+(int)((d.charAt(i)&0xff00)>>8)+", "+(int)(d.charAt(i)&0x00ff));
      if (((int)d.charAt(i))>32) {
        p.println(""+i+" "+(int)d.charAt(i)+" = "+d.charAt(i));
      }
      else {
        p.println(""+i+" "+(int)d.charAt(i));
      }
    }
    p.println("----------------------------------------------------------");
  }

}