/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.ssh;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.util.*;

import java.util.zip.*;

/** Zlib RFC 1950
 */

public class MJCSSHZLibCompression implements MJCSSHCompressionAlgorithm {
  
  // -------------------------------------------------------
  // Constants
  // -------------------------------------------------------
  
  // common  
  private static final String NAME="MJCSSHZLibCompression";
  private static final String VERSION="0.2";
    
  // -------------------------------------------------------
  // Variables
  // -------------------------------------------------------
    
  // common
  private MJCConverter converter;
  
  private Inflater inf;
  private Deflater def;
  private MJCStringBuffer strBufInf, strBufDef;
  private byte d_b[];
  private int d_read;
       
  // -------------------------------------------------------
  // Constructors
  // -------------------------------------------------------
 
  /** Default constructor for the class.
  */
  
  public MJCSSHZLibCompression() {
    
    // commonly used variables initalization
    converter=new MJCConverter();
    
    // DEFLATE
    strBufInf=new MJCStringBuffer(50000);    
    strBufDef=new MJCStringBuffer(50000);    
    inf=new Inflater();    
    def=new Deflater(9,false);    
//    def.setStrategy(Deflater.DEFLATED);
  }

  /** Returns the MJC name of the MJCSSHCompressionAlgorithm.
    * @return String: the MJC name of the MJCSSHCompressionAlgorithm
    */
  public String getCompressionAlgorithmName() {
    return NAME;
  }
    
  /** Returns the MJC version of the MJCSSHCompressionAlgorithm.
    * @return String: the MJC version of the MJCSSHCompressionAlgorithm.
    */
  public String getCompressionAlgorithmVersion() {
    return VERSION;
  }
    
  /** Compresses the given String.
    * @param String s: the to be compressed String
    * @return String: the compressed String
    */
  public String compress(String data) {
    try {
      return inflate(data);
    }
    catch (Exception e) {
      System.err.println("Exception in ZLIB compress: "+e.toString());
      return null;
    }  
  }
    
  /** Decompresses the given String.
    * @param String s: the to be decompressed String
    * @return String: the decompressed String
    */
  public String decompress(String data) {    
    try {
      return deflate(data);
    }  
    catch (Exception e) {
      System.err.println("Exception in ZLIB decompress: "+e.toString());
      return null;
    }  
  }
  
  private String deflate(String data) throws Exception {        
    inf.setInput(converter.getBytes(data));
    d_read=100;
    while (d_read==100) {
      d_b=new byte[100];
      d_read=inf.inflate(d_b);
      strBufInf.addToBuffer(d_b, d_read);
    } 
    return strBufInf.emptyBuffer();    
  }  
  
  private String inflate(String data) throws Exception {
    def.setInput(converter.getBytes(data));
    def.finish();
    System.out.println("inf data.len="+data.length());
    d_read=100;
    while (d_read==100) {
      d_b=new byte[100];
      d_read=def.deflate(d_b);      
      System.out.println("inf d_read="+d_read);
      strBufDef.addToBuffer(d_b, d_read);
    }          
    System.out.println("compressed len="+strBufDef.getBufferLength());
    //System.out.println("needsDict="+def.needsDictionary());
    System.out.println("needsInput="+def.needsInput());
    return strBufDef.emptyBuffer();    
    
  }
  
}