/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.util;

import com.monica.javacom.interfaces.*;

import java.util.*;

/** Class for providing MJCTimer functionality by using Thread.sleep to 
    measure the passed time.
*/    
public class MJCThreadTimer implements MJCTimer, Runnable {

  Vector children;
  Vector threads;
  MJCEqualityVector IDs;

  int myID;
  int myInterval;
  boolean status;
  Thread myThread;
  MJCTimerHandler myTimerHandler;

  /** Default constructor.
      @param MJCTimerHandler tH: the timerHandler that has to be notified at timer events
  */      
  public MJCThreadTimer(MJCTimerHandler tH) {
    threads=new Vector();
    children=new Vector();
    IDs=new MJCEqualityVector(new MJCIntegerEquality(), true, false, Integer.MAX_VALUE);
    myTimerHandler=tH;
  }

  private MJCThreadTimer(int id, int interv, MJCTimerHandler tH) {
    myID=id;
    myInterval=interv;
    status=false;
    myTimerHandler=tH;
  }

  private MJCThreadTimer(MJCTimerHandler tH, int ID) {
    myTimerHandler=tH;
    myID=ID;
    status=true;
  }

  private void setThread(Thread t) {
    myThread=t;
  }

  public synchronized boolean setTimer(int timerID, int interval) {
    if (IDs.firstIndex(new Integer(timerID), true)==-1) {
      MJCThreadTimer tt=new MJCThreadTimer(timerID, interval, myTimerHandler);
      Thread t=new Thread(tt);
      tt.setThread(t);

      IDs.add(new Integer(timerID));
      threads.addElement(t);
      children.addElement(tt);

      t.start();
      return true;
    }
    return false;
  }

  public synchronized boolean killTimer(int timerID) {
    int pos=IDs.firstIndex(new Integer(timerID), true);
    if (pos!=-1) {
      ((Thread)(threads.elementAt(pos))).interrupt();
      ((MJCThreadTimer)(children.elementAt(pos))).status=true;
      try {
        IDs.remove(pos);
      }
      catch (Exception e) {
      }
      threads.removeElementAt(pos);
      children.removeElementAt(pos);
      return true;
    }
    return false;
  }

  public void run() {
    if (status) {
      myTimerHandler.timerEvent(myID);
    }
    else {
      try {
        MJCThreadTimer tt;
        Thread t;
        while (!status) {
          myThread.sleep(myInterval);
          tt=new MJCThreadTimer(myTimerHandler, myID);
          t=new Thread(tt);
          t.start();
        }
      }
      catch (InterruptedException ie) {
      }
    }
  }

}