/************************************************************************
*
* Copyright (C) 2001 by 
* Kerenyi Kristof, Toth Gergely
*
* Team Monica Javacom, Package version 0.2
*
* Report any comments to javacom@tg.sch.bme.hu
* 
* Available under the GPL.
* 
* For more details about the copyright terms and conditions read the
* GNU Public License (GPL) available under www.gnu.org/copyleft/gpl.txt.
* 
*********************************************************************** */


package com.monica.javacom.window;

import com.monica.javacom.interfaces.*;
import com.monica.javacom.transport.*;
import com.monica.javacom.ciphering.*;
import com.monica.javacom.manager.*;
import com.monica.javacom.protocol.*;
import com.monica.javacom.terminal.*;
import com.monica.javacom.virtualinput.*;
import com.monica.javacom.virtualdisplay.*;
import com.monica.javacom.window.*;
import com.monica.javacom.application.*;
import com.monica.javacom.util.*;
import com.monica.javacom.ssh.*;

import java.io.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;

/** Class for implementing MJCSSHClient v0.2 as an Applet */
public class MJCSSHAppletWindow extends Applet implements MJCWindow {

  MJCVirtualDisplay content;
  MJCConfiguration configuration;
  MJCCloser closer;

  private static final String NAME="MJCSSHAppletWindow";
  private static final String VERSION="0.1";

  private static final String CONF_WINDOW_TITLE="windowTitle";
  private static final String CONF_DEF_WINDOW_TITLE="MONICA JavaCom SSH Terminal";

  public void init() {

    String MJCconf=new String(), fontsconf=new String();
    String errorString=new String();

    try {
      Class c=Class.forName("com.monica.javacom.util.MJCMJCConf");
      MJCMJCConf m=(MJCMJCConf)c.newInstance();
      MJCconf=m.retString();
      c=Class.forName("com.monica.javacom.util.MJCFontsConf");
      MJCFontsConf f=(MJCFontsConf)c.newInstance();
      fontsconf=f.retString();
    }
    catch (Exception e) {
      MJCconf=new String();
      fontsconf=new String();
      errorString=e.toString();
    }

    MJCConfiguration configuration=new MJCStringConfiguration(MJCconf);
    configuration.setStream("fonts.conf",new MJCStringInputStream(fontsconf));

    MJCTransport transport=new MJCTCPTransport();
    MJCSSHTransportLayer sshLayer=new MJCSSHTransportLayer();
    MJCTerminal terminal=new MJCVT220Terminal();
    MJCVirtualDisplay display=new MJCAWTDisplay(configuration);
    MJCVirtualInput input=new MJCKeyListener();

    transport.setReader(sshLayer);
    transport.setConfiguration(configuration);

    sshLayer.setWriteable(transport);
    sshLayer.setReadable(transport);
    sshLayer.setReader(terminal);
    sshLayer.setWindow(this);
    sshLayer.setTransport(transport);
    sshLayer.setConfiguration(configuration);

    terminal.setReadable(sshLayer);
    terminal.setConfiguration(configuration);
    terminal.setWriteable(sshLayer);
    terminal.setVirtualDisplay(display);

    setConfiguration(configuration);
    setCloser(sshLayer);

    input.setConfiguration(configuration);
    input.setWriteable(terminal);

    Dimension d=((Canvas)display).getSize();
    ((Canvas)display).addKeyListener((KeyListener)input);
    addKeyListener((KeyListener)input);
    add((Canvas)display);
    setBackground(((Canvas)display).getBackground());
    setSize(new Dimension(d.width+20, d.height+40));

    display.clear();
    display.setCPos(0,0);
    display.addS("Running...");
    display.newLine();
    display.setCPosX(0);
    display.refresh();

    display.addS(errorString);

    String host=new String("tg.sch.bme.hu");
    String port=new String();
    int iPort=22;
    try {
      host=getParameter("host");
      port=getParameter("port");
      iPort=Integer.parseInt(port);
    }
    catch (Exception e) {
    }

    try {
      transport.initAsClient(host,iPort);
    }
    catch (Exception e) {
      display.clear();
      display.setCPos(0,0);
      display.addS("Connection to the server could not be established. Reason: "+e.toString());
      display.refresh();
    }
  }

  /** Returns the MJC name of the MJCWindow.
      @return String: the MJC name of the MJCWindow
  */
  public String getWindowName() {
    return NAME;
  }

  /** Returns the MJC version of the MJCWindow.
      @return String: the MJC version of the MJCWindow
  */
  public String getWindowVersion() {
    return VERSION;
  }

  /** Sets the MJCConfiguration for this object.
      @param MJCConfiguration configuration: the MJCConfiguration
        object for the customization
  */
  public void setConfiguration(MJCConfiguration configuration) {
    this.configuration=configuration;
  }

  /** Returns the MJCConfiguration with which this object is customized.
      @return MJCConfiguration: the MJCConfiguration with which this
        object is customized
  */
  public MJCConfiguration getConfiguration() {
    return configuration;
  }

  /** Sets the MJCCloser responsible for closing of the client
      side application upon user request.
      @param MJCCloser closer: the MJCCloser reponsible for the
        closing of the client side application upon user request
  */
  public void setCloser(MJCCloser closer) {
    this.closer=closer;
//    addWindowListener(new MJCAWTWindowWindowCloser(closer, this));
  }

  /** Returns the MJCCloser responsible for the closing of the
      client side application upon user request.
      @return MJCCloser: the MJCCloser responsible for the closing
        of the client side application upon user request
  */
  public MJCCloser getCloser() {
    return closer;
  }

}